nb_maps_flutter library

Classes

Annotation
AnnotationManager<T extends Annotation>
ArgumentCallbacks<T>
Mutable collection of ArgumentCallback instances, itself an ArgumentCallback.
CameraPosition
The position of the map "camera", the view point from which the world is shown in the map view. Aggregates the camera's target geographical location, its zoom level, tilt angle, and bearing.
CameraTargetBounds
Bounds for the map camera target.
CameraUpdate
Defines a camera move, supporting absolute moves as well as moves relative the current position.
Circle
CircleLayerProperties
CircleManager
CircleOptions
Configuration options for Circle instances.
DownloadRegionStatus
Error
Expressions
Fill
FillExtrusionLayerProperties
FillLayerProperties
FillManager
FillOptions
Configuration options for Fill instances.
GeojsonSourceProperties
HeatmapLayerProperties
HillshadeLayerProperties
ImageSourceProperties
InProgress
LatLng
A pair of latitude and longitude coordinates, stored as degrees.
LatLngBounds
A latitude/longitude aligned rectangle.
LatLngQuad
A geographical area representing a non-aligned quadrilateral This class does not wrap values to the world bounds
LayerProperties
Line
LineLayerProperties
LineManager
LineOptions
Configuration options for Line instances.
MethodChannelNbMapsGl
MinMaxZoomPreference
Preferred bounds for map camera zoom level.
NbDefaultStyle
NBMap
NbMapsGlPlatform
NbMapStyles
NextBillion
NextBillion class provides static methods for initializing and configuring the NextBillion Maps SDK.
NextbillionMapController
Controller for a single NBMap instance running on the host platform.
NextBillionMapOptions
Configuration options for the NbMaps user interface.
OfflineRegion
Description of a downloaded region including its identifier.
OfflineRegionDefinition
Description of region to be downloaded. Identifier will be generated when the download is initiated.
PlatformWrapper
PlatformWrapperImpl
RasterDemSourceProperties
RasterLayerProperties
RasterSourceProperties
SnapshotOptions
Set of options for taking map snapshot
SourceProperties
Success
Symbol
SymbolLayerProperties
SymbolManager
SymbolOptions
Configuration options for Symbol instances.
UserHeading
Type represents a geomagnetic value, measured in microteslas, relative to a device axis in three dimensional space.
UserLocation
User's observed location
VectorSourceProperties
VideoSourceProperties

Enums

AnnotationType
AttributionButtonPosition
Attribution Button Position
CompassViewPosition
Compass View Position
DragEventType
MyLocationRenderMode
Render mode
MyLocationTrackingMode
The camera mode, which determines how the map camera will track the rendered location.
NBMapStyleType
WellKnownTileServer

Properties

globalChannel MethodChannel
getter/setter pair

Functions

buildFeatureCollection(List<Map<String, dynamic>> features) Map<String, dynamic>
deleteOfflineRegion(int id, {String? accessToken}) Future
downloadOfflineRegion(OfflineRegionDefinition definition, {Map<String, dynamic> metadata = const {}, String? accessToken, dynamic onEvent(DownloadRegionStatus event)?, EventChannelCreator? eventChannelCreator}) Future<OfflineRegion>
getListOfRegions({String? accessToken}) Future<List<OfflineRegion>>
getRandomString([int length = 10]) String
installOfflineMapTiles(String tilesDb) Future<void>
Copy tiles db file passed in to the tiles cache directory (sideloaded) to make tiles available offline.
mergeOfflineRegions(String path, {String? accessToken}) Future<List<OfflineRegion>>
setHttpHeaders(Map<String, String> headers) Future<void>
setOffline(bool offline, {String? accessToken}) Future
setOfflineTileCountLimit(int limit, {String? accessToken}) Future
setTestingGlobalChannel(MethodChannel channel) → void
translateFillOptions(FillOptions options, LatLng delta) FillOptions
updateOfflineRegionMetadata(int id, Map<String, dynamic> metadata, {String? accessToken}) Future<OfflineRegion>

Typedefs

ArgumentCallback<T> = void Function(T argument)
Callback function taking a single argument.
EventChannelCreator = EventChannel Function(String name)
MapCreatedCallback = void Function(NextbillionMapController controller)
OnAttributionClickCallback = void Function()
OnCameraIdleCallback = void Function()
OnCameraTrackingChangedCallback = void Function(MyLocationTrackingMode mode)
OnCameraTrackingDismissedCallback = void Function()
OnFeatureDragnCallback = dynamic Function(dynamic id, {required LatLng current, required LatLng delta, required DragEventType eventType, required LatLng origin, required Point<double> point})
OnFeatureInteractionCallback = void Function(dynamic id, Point<double> point, LatLng coordinates)
OnMapClickCallback = void Function(Point<double> point, LatLng coordinates)
OnMapIdleCallback = void Function()
OnMapLongClickCallback = void Function(Point<double> point, LatLng coordinates)
OnPlatformViewCreatedCallback = void Function(int)
OnStyleLoadedCallback = void Function()
OnUserLocationUpdated = void Function(UserLocation location)